# WinTheme
Simple manipulating with window theme
# Examples
There are PyGame and PyQt examples available in [Github Repository](https://github.com/Pixelsuft/wintheme/)
# Installing
```sh
python -m pip install wintheme
```
